package com.zehong.communication.controller;

import com.zehong.communication.common.result.Result;
import com.zehong.communication.common.result.ResultEnum;
import com.zehong.communication.model.SendAliVoiceNotify;
import com.zehong.communication.service.AliVoiceNotifyService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * @author gengd
 * 阿里语音通知
 */
@RestController
@RequestMapping("/aliVoiceNotify")
public class AliVoiceNotifyController {

    private static final Logger logger = LoggerFactory.getLogger(AliVoiceNotifyController.class);

    @Autowired
    private AliVoiceNotifyService aliVoiceNotifyService;

    /**
     * 发送阿里语音
     * @param sendAliVoiceNotify 阿里语音
     * @param result 返回结果
     * @return Result
     */
    @RequestMapping(value = "/sendAliVoiceNotify",method = RequestMethod.POST)
    public Result sendAliVoiceNotify(@Valid @RequestBody SendAliVoiceNotify sendAliVoiceNotify, BindingResult result){
        try {
            if(result.hasErrors()){
                return new Result(ResultEnum.VALIDATA_ERROR.getCode(),result.getFieldError().getDefaultMessage());
            }
            return aliVoiceNotifyService.sendAliVoiceNotify(sendAliVoiceNotify);
        } catch (Exception e) {
            logger.error("阿里语音发送失败,phoneNumbers:%",sendAliVoiceNotify.getCalledNumber(),e);
            return new Result(ResultEnum.SYSTEM_EXCEPTION);
        }
    }
}
