package com.zehong.communication.controller;

import com.aliyuncs.exceptions.ClientException;
import com.zehong.communication.common.result.Result;
import com.zehong.communication.common.result.ResultEnum;
import com.zehong.communication.model.SendBatchSms;
import com.zehong.communication.model.SendSms;
import com.zehong.communication.service.SmsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * 发送短信
 * @author gengdidi
 */
@RestController
@RequestMapping("/sms")
public class SmsController {

    private static final Logger logger = LoggerFactory.getLogger(SmsController.class);

    @Autowired
    private SmsService smsService;

    /**
     * 短信发送
     * @param sendSms 短信实体
     * @return Result
     */
    @RequestMapping(value="/sendSms",method = RequestMethod.POST)
    public Result sendSms(@Valid @RequestBody SendSms sendSms, BindingResult result){
        try {
            if(result.hasErrors()){
                return new Result(ResultEnum.VALIDATA_ERROR.getCode(),result.getFieldError().getDefaultMessage());
            }
            return smsService.sendSms(sendSms);
        } catch (ClientException e) {
            logger.info("短信发送失败，phoneNumber:%",sendSms.getPhoneNumber(),e);
            return new Result(ResultEnum.SYSTEM_EXCEPTION);
        }
    }

    /**
     * 群发短信
     * @param sendBatchSms 群发短信实体
     * @return Result
     */
    @RequestMapping(value="/sendBatchSms",method = RequestMethod.POST)
    public Result sendBatchSms(@Valid @RequestBody SendBatchSms sendBatchSms, BindingResult result){
        try {
            if(result.hasErrors()){
                return new Result(ResultEnum.VALIDATA_ERROR.getCode(),result.getFieldError().getDefaultMessage());
            }
            return smsService.sendBatchSms(sendBatchSms);
        } catch (ClientException e) {
            logger.info("批量发送短信失败,phoneNumbers:%",sendBatchSms.getPhoneNumberJson(),e);
            return new Result(ResultEnum.SYSTEM_EXCEPTION);
        }
    }
}
