package com.zehong.communication.model;

import lombok.Data;
import org.hibernate.validator.constraints.NotBlank;
import org.hibernate.validator.constraints.NotEmpty;

import javax.validation.constraints.Pattern;

@Data
public class SendAliVoiceNotify extends BaseRequestModel {

    /**
     * 若您使用的文本转语音模板为公共模式外呼，则该参数值不填。
     * */
    private String calledShowNumber;

    /**
     * 接收语音通知的手机号码
     * 一次请求仅支持一个被叫号，使用流程，请参见国内语音通知使用流程或国际/港澳台语音验证码使用流程。
     *语音验证码流控频率规则：同一个被叫，1次/分钟、5次/小时、20次/24小时。
     */

    @NotEmpty(message = "接收语音通知的手机号码不能为空")
    @Pattern(regexp = "^1[0-9]{10}$", message = "接收语音通知的手机号不合法")
    private String calledNumber;

    /**
     * 已通过审核的语音验证码模板ID
     */
    @NotBlank(message = "语音验证码模板id不能为空")
    private String ttsCode;

    /**
     * 模板中的变量参数，JSON格式
     * {"AckNum":"123456"}
     */
    @NotBlank(message = "语音模板不能为空")
    private String ttsParam;

    /**
     * 非必填
     * 一通电话内语音通知内容的播放次数。取值范围：1~3，默认取值3
     */
    private int playTimes;

    /**
     * 非必填
     * 语音通知的播放音量。取值范围：0~100，默认取值100。
     */
    private int volume = -1;

    /**
     * 非必填
     * 语速控制。取值范围为：-500~500。
     */
    private int speed = 555;

    /**
     * 非必填
     * 发起请求时预留给调用方的自定义ID，最终会通过在回执消息中将此ID带回给调用方。
     *字符串类型，长度为1~15个字节。
     */
    private String outId;
}
